from .artifact import Artifact
from .cluster import Cluster
from .dataset import Dataset, VolumeOptions
from .deployment import Deployment, AutoscalingDefinition, AutoscalingMetric
from .experiment import BaseExperiment, MultiNodeExperiment, SingleNodeExperiment, MpiMultiNodeExperiment
from .hyperparameter import Hyperparameter
from .job import Job
from .log import LogRow
from .machine import Machine, MachineEvent, MachineUtilization
from .model import Model, ModelFile
from .notebook import Notebook, NotebookStart
from .project import Project
from .secret import Secret
from .tag import Tag
from .tensorboard import Instance, Tensorboard
from .vm_type import VmType, VmTypeGpuModel



from ..sdk_exceptions import GradientSdkError
from ..serializers import SingleNodeExperimentSchema, MultiNodeExperimentSchema, HyperparameterSchema, \
    MpiMultiNodeExperimentSchema

EXPERIMENT_ID_TO_EXPERIMENT_SERIALIZER_MAPPING = {
    1: SingleNodeExperimentSchema,
    2: MultiNodeExperimentSchema,
    3: MpiMultiNodeExperimentSchema,
    4: HyperparameterSchema,
}


def get_serializer_for_experiment(experiment_dict):
    """
    :param dict experiment_dict:
    :rtype: serializers.BaseExperimentSchema
    """
    experiment_type_id = experiment_dict["experimentTypeId"]

    try:
        serializer = EXPERIMENT_ID_TO_EXPERIMENT_SERIALIZER_MAPPING[experiment_type_id]
    except KeyError as e:
        raise GradientSdkError("No experiment type with ID: {}".format(str(e)))

    return serializer



from .clusters import ListClusters
from .deployments import ListDeployments, CreateDeployment, StartDeployment, StopDeployment, DeleteDeployment, \
    UpdateDeployment, GetDeployment, GetDeploymentMetrics, StreamDeploymentMetrics, ListDeploymentLogs
from .experiments import ListExperiments, GetExperiment, ListExperimentLogs, StartExperiment, StopExperiment, \
    CreateSingleNodeExperiment, CreateMultiNodeExperiment, RunSingleNodeExperiment, RunMultiNodeExperiment, \
    CreateMpiMultiNodeExperiment, RunMpiMultiNodeExperiment, DeleteExperiment, GetExperimentMetrics, \
    StreamExperimentMetrics
from .hyperparameter import CreateHyperparameterJob, CreateAndStartHyperparameterJob, ListHyperparameterJobs, \
    GetHyperparameterTuningJob, StartHyperparameterTuningJob
from .jobs import ListJobs, ListResources, ListJobArtifacts, ListJobLogs, GetJob, GetJobMetrics, StreamJobMetrics
from .machine_types import ListMachineTypes
from .machines import CheckMachineAvailability, CreateMachine, CreateResource, StartMachine, StopMachine, \
    RestartMachine, GetMachine, UpdateMachine, GetMachineUtilization
from .models import DeleteModel, ListModels, UploadModel, GetModel, ListModelFiles
from .notebooks import CreateNotebook, DeleteNotebook, GetNotebook, ListNotebooks, GetNotebookMetrics, \
    StreamNotebookMetrics, StopNotebook, StartNotebook, ForkNotebook, ListNotebookArtifacts, ListNotebookLogs
from .projects import CreateProject, ListProjects, DeleteProject, GetProject
from .secrets import ListSecrets, SetSecret, DeleteSecret
from .tensorboards import CreateTensorboard, GetTensorboard, ListTensorboards, UpdateTensorboard, DeleteTensorboard
